@@ -261,7 +261,7 @@ class UserAuthHelper:
         # HACK TEMP: allow updating authIdCognito to a new value since we're switching user pools
 #         condition_expression = '(  authIdCognito = :authIdCognito OR attribute_not_exists(authIdCognito)  ) ' \
 #                                  ' AND (unverifiedEmail = :email OR attribute_not_exists(unverifiedEmail) ) '
-        condition_expression = '(unverifiedEmail = :email OR attribute_not_exists(unverifiedEmail)'
+        condition_expression = '(unverifiedEmail = :email OR attribute_not_exists(unverifiedEmail))'
         try:
 
             response = self.user_table.update_item(
